/* Copyright (c) 2006 Dirk Jagdmann <doj@cubic.org>

This software is provided 'as-is', without any express or implied
warranty. In no event will the authors be held liable for any damages
arising from the use of this software.

Permission is granted to anyone to use this software for any purpose,
including commercial applications, and to alter it and redistribute it
freely, subject to the following restrictions:

    1. The origin of this software must not be misrepresented; you
       must not claim that you wrote the original software. If you use
       this software in a product, an acknowledgment in the product
       documentation would be appreciated but is not required.

    2. Altered source versions must be plainly marked as such, and
       must not be misrepresented as being the original software.

    3. This notice may not be removed or altered from any source
       distribution. */

/* $Header: /code/qtpod/qtpod.hpp,v 1.13 2006/07/31 10:35:32 doj Exp $ */

#ifndef QTPOD__HPP
#define QTPOD__HPP

#define QTPOD_VERSION "1.2"

#include <stdint.h>

#include <qapplication.h>

class Q3ButtonGroup;
class QLabel;
class QCheckBox;
class QSlider;
class QComboBox;
class QWidget;
class QPushButton;
class QRadioButton;

class QTPOD : public QApplication
{
  Q_OBJECT

  Q3ButtonGroup *bg;
  QRadioButton* bgbut[4*9+2];
  QString presetname[4*9+2];
  QLabel *title;
  QCheckBox *sw_distortion, *sw_drive, *sw_eq, *sw_delay, *sw_tremolo, *sw_reverb, *sw_noise, *sw_bright;

  QComboBox *preamp_ampmodel;
  QSlider *preamp_drive, *preamp_drive2, *preamp_bass, *preamp_mid, *preamp_treble, *preamp_presence, *preamp_chanvol;

  QSlider *ng_threshold, *ng_decay;

  QSlider *wah_level, *wah_botfreq, *wah_topfreq;
  QCheckBox *wah_enable;

  QSlider *volpedal_level, *volpedal_min;
  QCheckBox *volpedal_pos;

  QSlider *delay_time1, *delay_feedback1, *delay_level1;

  Q3ButtonGroup *reverb_type;
  QSlider *reverb_decay, *reverb_tone, *reverb_diffusion, *reverb_density, *reverb_level;

  QComboBox *cab_type;
  QSlider *cab_air;

  QComboBox *fx_type;
  QSlider *fx_tweak;

  QSlider *swell_time, *comp_ration,
    *chorus_speed, *chorus_depth, *chorus_feedback, *chorus_delay,
    *rotary_fast, *rotary_slow,
    *tremolo_speed, *tremolo_depth;
  QCheckBox *rotary_curr;

  QSlider *dig_gain;

  QString podname, patchname;
  int patchversion;

  QPushButton *taptempo_but;

  bool podfound;

public:
  QTPOD(int argc, char **argv);
  ~QTPOD();

  void parsesysex(const uint8_t *buf, const unsigned len);
  void parsecontroller(const int c, const int v);
  void setCaption();
  void updatebrightsw(int i);
  void taptempo(int i);

public slots:
  void newpreset(int id);
  void midievent(int);
  void sendpodquery();
  void sendpatchquery();
  void sendallquery();
  void taptempo_resetbg();

  void sw_distortion_slot(bool);
  void sw_drive_slot(bool);
  void sw_eq_slot(bool);
  void sw_delay_slot(bool);
  void sw_tremolo_slot(bool);
  void sw_reverb_slot(bool);
  void sw_noise_slot(bool);
  void sw_bright_slot(bool);

  void preamp_model_slot(int);
  void preamp_drive_slot(int);
  void preamp_drive2_slot(int);
  void preamp_bass_slot(int);
  void preamp_mid_slot(int);
  void preamp_treble_slot(int);
  void preamp_presence_slot(int);
  void preamp_chanvol_slot(int);

  void ng_threshold_slot(int);
  void ng_decay_slot(int);

  void wah_level_slot(int);
  void wah_botfreq_slot(int);
  void wah_topfreq_slot(int);
  void wah_enable_slot(bool);

  void volpedal_level_slot(int);
  void volpedal_min_slot(int);
  void volpedal_pos_slot(bool);

  void delay_time1_slot(int);
  void delay_feedback1_slot(int);
  void delay_level1_slot(int);

  void reverb_type_slot(int);
  void reverb_decay_slot(int);
  void reverb_tone_slot(int);
  void reverb_diffusion_slot(int);
  void reverb_density_slot(int);
  void reverb_level_slot(int);

  void cab_type_slot(int);
  void cab_air_slot(int);

  void fx_type_slot(int);
  void fx_tweak_slot(int);

  void swell_time_slot(int);
  void comp_ration_slot(int);
  void chorus_speed_slot(int);
  void chorus_depth_slot(int);
  void chorus_feedback_slot(int);
  void chorus_delay_slot(int);
  void rotary_curr_slot(bool);
  void rotary_fast_slot(int);
  void rotary_slow_slot(int);
  void tremolo_speed_slot(int);
  void tremolo_depth_slot(int);

  void dig_gain_slot(int);

  void taptempo_slot();

  void restore_geometry_slot();
};

#endif
